@@ -67,7 +67,8 @@ class RedshiftClustersCommon(core.Construct):
         self.env_name = team_space_props["env_name"]
         self.teamspace_name = team_space_props["teamspace_name"]
         self.lake_role_name = team_space_props["lake_role_name"]
-        self.lake_role_arn = f"arn:{self.partition}:iam::{self.account}:role/{self.lake_role_name}"
+        self.role_prefix = team_space_props["role_prefix"]
+        self.lake_role_arn = f"arn:{self.partition}:iam::{self.account}:role{self.role_prefix}{self.lake_role_name}"
         self.team_security_group_id = team_space_props["team_security_group_id"]
         self.team_kms_key_arn = team_space_props["team_kms_key_arn"]
 
@@ -124,6 +125,7 @@ class RedshiftClustersCommon(core.Construct):
             self,
             "lambda_orbit_lake_formation_trigger",
             assumed_by=cast(iam.IPrincipal, iam.ServicePrincipal("lambda.amazonaws.com")),
+            path=self.role_prefix,
             inline_policies={
                 "lambda-policy": iam.PolicyDocument(
                     statements=[
@@ -190,13 +192,14 @@ class RedshiftFunctionStandard(core.Construct):
         env_name: str = redshift_common.env_name
         teamspace_name: str = redshift_common.teamspace_name
         code = aws_lambda.Code.asset(_lambda_path(path="redshift_db_creator"))
+        region: str = redshift_common.region
 
         if redshift_common.lake_role_arn is None:
             raise ValueError("Orbit lake role arn required")
 
         lake_role = iam.Role.from_role_arn(
             self,
-            f"{env_name}-{teamspace_name}-role",
+            f"{env_name}-{teamspace_name}-{region}-role",
             redshift_common.lake_role_arn,
             mutable=False,
         )
@@ -255,14 +258,10 @@ class RedshiftStack(Stack):
             "partition": core.Aws.PARTITION,
             "env_name": context.name,
             "teamspace_name": team_context.name,
-            "lake_role_name": f"orbit-{context.name}-{team_context.name}-role",
+            "lake_role_name": f"orbit-{context.name}-{team_context.name}-{context.region}-role",
+            "role_prefix": f"/{context.role_prefix}/" if context.role_prefix else "/",
             "vpc_id": context.networking.vpc_id,
-            "subnet_ids": [
-                s.subnet_id
-                for s in context.networking.public_subnets
-                + context.networking.isolated_subnets
-                + context.networking.private_subnets
-            ],
+            "subnet_ids": context.networking.data.nodes_subnets,
             "team_security_group_id": team_context.team_security_group_id,
             "team_kms_key_arn": team_context.team_kms_key_arn,
         }
